@@ -3,20 +3,19 @@ from IPython.display import Math, display, Markdown
 from sympy import latex
 from math import sqrt, pi
 import pint
+import os
+import re
 
 u = pint.UnitRegistry()
-Q = u.Quantity
-
-u.default_format = "~P.5g"
-
-
-
+u.default_format = "~H.5g"
 
 
 class Equations:
     def __init__(self):
         self.items = {"Top": ["Variable", "Answer", "Equation_fill", "Equation", "Ref"]}
         self.maxes = []
+        self.greens = []
+        self.reds = []
 
     def additem(self, value, equation):
         self.items[(value)] = equation
@@ -39,32 +38,145 @@ class Equations:
         for key, value in self.items.items():
             print(key)
 
-    def displayfancy(self, *highs):
+    def markfull(self, *highs):
+        mymarkdown = ""
         a, b, c, d, e = 0, 0, 0, 0, 0
-
-        # maxes = ["P_n", "Slenderness"]
         for max in self.maxes:
             highs += (max,)
 
+        spacing = 1
         for key, value in self.items.items():
             for i, item in enumerate(value):
                 # print(item)
                 if i == 0:
                     if len(str(item)) > a:
-                        a = len(str(item)) + 2
+                        a = len(str(item)) + spacing
                         # print(l)
                 if i == 1:
                     if len(str(item)) > b:
-                        b = len(str(item)) + 2
+                        b = len(str(item)) + spacing
                 if i == 2:
                     if len(str(item)) > c:
-                        c = len(str(item)) + 2
+                        c = len(str(item)) + spacing
                 if i == 3:
                     if len(str(item)) > d:
-                        d = len(str(item)) + 2
+                        d = len(str(item)) + spacing
                 if i == 4:
                     if len(str(item)) > e:
-                        e = len(str(item)) + 2
+                        e = len(str(item)) + spacing
+        # print(a,b,c,d,e)
+        a, b, c, d, e = e, a, d, c, b
+        for key, value in self.items.items():
+            # if key in ["A_g", "A_n", "A_e"]:
+
+            # Use this to determine keys
+            # print(key)
+            variable = value[0]
+            solution = value[1]
+            equation_fill = value[2]
+            equation = value[3]
+            ref = value[4]
+
+            try:
+                if key in highs:
+                    mymarkdown += f"\n{ref} | <span style='color:blue'>{variable}</span> | {(equation)} | {(equation_fill)} | <span style='color:blue'>{solution:.5g}</span>"
+                elif key in self.reds:
+                    mymarkdown += f"\n{ref} | <span style='color:red'>{variable}</span> | {(equation)} | {(equation_fill)} | <span style='color:red'>{solution:.5g}</span>"
+                elif key in self.greens:
+                    mymarkdown += f"\n{ref} | <span style='color:green'>{variable}</span> | {(equation)} | {(equation_fill)} | <span style='color:green'>{solution:.5g}</span>"
+                else:
+                    mymarkdown += f"\n{ref}  | {variable} | {(equation)} | {(equation_fill)} | {solution:.5g}"
+            except:
+                mymarkdown += (
+                    # f"{ref:<{a}}  | {variable:<{b}} | {(equation):<{c}} | {(equation_fill):<{d}} | {solution:<{e}}\n{'-' * (a + b + c + d + e + 6)}"
+                    f"{ref}  | {variable} | {(equation)} | {(equation_fill)} | {solution}\n:-:|:-:|:-:|:-:|:-:"
+                )
+
+            # except:
+            #     print(f"{ref}{variable:<{a}}   {'':<{b}} | {solution:>{c}.3g}")
+        display(Markdown(mymarkdown))
+        # print(mymarkdown)
+        print("\n" * 3)
+
+    def markans(self, *highs):
+        mymarkdown = ""
+        a, b, c, d, e = 0, 0, 0, 0, 0
+        for max in self.maxes:
+            highs += (max,)
+        spacing = 1
+        for key, value in self.items.items():
+            for i, item in enumerate(value):
+                # print(item)
+                if i == 0:
+                    if len(str(item)) > a:
+                        a = len(str(item)) + spacing
+                        # print(l)
+                if i == 1:
+                    if len(str(item)) > b:
+                        b = len(str(item)) + spacing
+                if i == 2:
+                    if len(str(item)) > c:
+                        c = len(str(item)) + spacing
+                if i == 3:
+                    if len(str(item)) > d:
+                        d = len(str(item)) + spacing
+                if i == 4:
+                    if len(str(item)) > e:
+                        e = len(str(item)) + spacing
+        # print(a,b,c,d,e)
+        a, b, c, d, e = e, a, d, c, b
+        for key, value in self.items.items():
+            # if key in ["A_g", "A_n", "A_e"]:
+
+            # Use this to determine keys
+            # print(key)
+            variable = value[0]
+            solution = value[1]
+            equation_fill = value[2]
+            equation = value[3]
+            ref = value[4]
+
+            try:
+                if key in highs:
+                    mymarkdown += f"\n**{variable}** | **{solution:.5g}**"
+                else:
+                    mymarkdown += f"\n{variable} | {solution:.5g}"
+            except:
+                mymarkdown += (
+                    # f"{ref:<{a}}  | {variable:<{b}} | {(equation):<{c}} | {(equation_fill):<{d}} | {solution:<{e}}\n{'-' * (a + b + c + d + e + 6)}"
+                    f"{variable} | {solution}\n:-:|:-:"
+                )
+
+            # except:
+            #     print(f"{ref}{variable:<{a}}   {'':<{b}} | {solution:>{c}.3g}")
+        display(Markdown(mymarkdown))
+        # print(mymarkdown)
+        print("\n" * 3)
+
+    def displayfull(self, *highs):
+        a, b, c, d, e = 0, 0, 0, 0, 0
+        for max in self.maxes:
+            highs += (max,)
+        spacing = 1
+        for key, value in self.items.items():
+            for i, item in enumerate(value):
+                # print(item)
+                if i == 0:
+                    if len(str(item)) > a:
+                        a = len(str(item)) + spacing
+                        # print(l)
+                if i == 1:
+                    if len(str(item)) > b:
+                        b = len(str(item)) + spacing
+                if i == 2:
+                    if len(str(item)) > c:
+                        c = len(str(item)) + spacing
+                if i == 3:
+                    if len(str(item)) > d:
+                        d = len(str(item)) + spacing
+                if i == 4:
+                    if len(str(item)) > e:
+                        e = len(str(item)) + spacing
         # print(a,b,c,d,e)
         a, b, c, d, e = e, a, d, c, b
         for key, value in self.items.items():
@@ -81,7 +193,7 @@ class Equations:
             try:
                 if key in highs:
                     print(
-                        f"{color.YELLOW}{ref:<{a}}  | {variable:<{b}} | {(equation):<{c}} | {(equation_fill):<{d}} | {solution:>{e}.5g}{color.END}"
+                        f"{color.YELLOW}{color.BOLD}{ref:<{a}}  | {variable:<{b}} | {(equation):<{c}} | {(equation_fill):<{d}} | {solution:>{e}.5g}{color.END}"
                     )
                 else:
                     print(
@@ -89,8 +201,61 @@ class Equations:
                     )
             except:
                 print(
-                    f"{ref:<{a}}  | {variable:<{b}} | {(equation):<{c}} | {(equation_fill):<{d}} | {solution:<{e}}\n{'-' * (a + b + c + d + e + 6)}"
+                    # f"{ref:<{a}}  | {variable:<{b}} | {(equation):<{c}} | {(equation_fill):<{d}} | {solution:<{e}}\n{'-' * (a + b + c + d + e + 6)}"
+                    f"{ref:<{a}}  | {variable:<{b}} | {(equation):<{c}} | {(equation_fill):<{d}} | {solution:<{e}}\n{'-'*a}|{'-'*b}|{'-'*c}|{'-'*d}|{'-'*e}"
                 )
+
+            # except:
+            #     print(f"{ref}{variable:<{a}}   {'':<{b}} | {solution:>{c}.3g}")
+        print("\n" * 3)
+
+    def displayans(self, *highs):
+        # only prints Variable(b) and Answer(e)
+        a, b, c, d, e = 0, 0, 0, 0, 0
+        for max in self.maxes:
+            highs += (max,)
+        spacing = 1
+        for key, value in self.items.items():
+            for i, item in enumerate(value):
+                # print(item)
+                if i == 0:
+                    if len(str(item)) > a:
+                        a = len(str(item)) + spacing
+                        # print(l)
+                if i == 1:
+                    if len(str(item)) > b:
+                        b = len(str(item)) + spacing
+                if i == 2:
+                    if len(str(item)) > c:
+                        c = len(str(item)) + spacing
+                if i == 3:
+                    if len(str(item)) > d:
+                        d = len(str(item)) + spacing
+                if i == 4:
+                    if len(str(item)) > e:
+                        e = len(str(item)) + spacing
+        # print(a,b,c,d,e)
+        a, b, c, d, e = e, a, d, c, b
+        for key, value in self.items.items():
+            # if key in ["A_g", "A_n", "A_e"]:
+
+            # Use this to determine keys
+            # print(key)
+            variable = value[0]
+            solution = value[1]
+            equation_fill = value[2]
+            equation = value[3]
+            ref = value[4]
+
+            try:
+                if key in highs:
+                    print(
+                        f"{color.YELLOW}{color.BOLD}{variable:<{b}} | {solution:>{e}.5g}{color.END}"
+                    )
+                else:
+                    print(f"{variable:<{b}} | {solution:>{e}.5g}")
+            except:
+                print(f"{variable:<{b}} | {solution:<{e}}\n{'-' * b} | {'-'*e}")
             # except:
             #     print(f"{ref}{variable:<{a}}   {'':<{b}} | {solution:>{c}.3g}")
         print("\n" * 3)
@@ -132,40 +297,6 @@ class Load:
         self.W = Wind * u.kips
         self.myeqns = Equations()
 
-    def get_combo_loads(self):
-        D = self.D
-        L = self.L
-        L_r = self.L_r
-        S = self.S
-        R = self.R
-        W = self.W
-
-        omega = 1.67
-        phi = 0.9
-        mymax = 0
-
-        #     LRFD
-        print("LRFD")
-        for i in range(1, 6):
-            combo_value_LRFD = self.combo_loads("LRFD", i)
-
-            print(f"Combination {i} = {(combo_value_LRFD):.3g}")
-            if combo_value_LRFD > mymax:
-                mymax, mymax_i = combo_value_LRFD, i
-        print(f"max = {mymax:.3g}")
-        print(f"max / phi = {(mymax / phi):.3g}")
-
-        mymax = 0
-        print("")
-        print("ASD")
-        for i in range(1, 8):
-            combo_value_ASD = self.combo_loads("ASD", i)
-            print(f"Combination {i} = {(combo_value_ASD):.3g}")
-            if combo_value_ASD > mymax:
-                mymax, mymax_i = combo_value_ASD, i
-        print(f"max = {mymax:.3g}")
-        print(f"max * omega = {(mymax * omega):.3g}")
-
     def combo_loads(self, load_type, combo):
         D = self.D
         L = self.L
@@ -182,7 +313,7 @@ class Load:
                         1.4 * D,
                         f"1.4 * {D}",
                         "1.4 * D",
-                        "ASCE 7 Load Combination",
+                        "ASCE 7",
                     ],
                 )
                 return 1.4 * D
@@ -194,7 +325,7 @@ class Load:
                         1.2 * D + 1.6 * L + 0.5 * (max(L_r, S, R)),
                         f"1.2 * {D} + 1.6 * {L} + 0.5 * {(max(L_r, S, R))}",
                         "1.2 * D + 1.6 * L + 0.5 * (max(L_r, S, R))",
-                        "ASCE 7 Load Combination",
+                        "ASCE 7",
                     ],
                 )
                 return 1.2 * D + 1.6 * L + 0.5 * (max(L_r, S, R))
@@ -206,7 +337,7 @@ class Load:
                         1.2 * D + 1.6 * max(L_r, S, R) + max(0.5 * L, 0.5 * W),
                         f"1.2 * {D} + 1.6 * {max(L_r, S, R)} + {max(0.5 * L, 0.5 * W)}",
                         "1.2 * D + 1.6 * max(L_r, S, R) + max(0.5 * L, 0.5 * W)",
-                        "ASCE 7 Load Combination",
+                        "ASCE 7",
                     ],
                 )
 
@@ -219,8 +350,8 @@ class Load:
                         "LRFD Combo " + str(combo),
                         1.2 * D + 1.0 * W + 1.0 * L + 0.5 * max(L_r, S, R),
                         f"1.2 * {D} + 1.0 * {W} + 1.0 * {L} + 0.5 * {max(L_r, S, R)}",
-                        "1.2 * {D} + 1.0 * {W} + 1.0 * {L} + 0.5 * {max(L_r, S, R)}",
-                        "ASCE 7 Load Combination",
+                        "1.2 * D + 1.0 * W + 1.0 * L + 0.5 * max(L_r, S, R)",
+                        "ASCE 7",
                     ],
                 )
 
@@ -232,8 +363,8 @@ class Load:
                         "LRFD Combo " + str(combo),
                         0.9 * D + 1.0 * W,
                         f"0.9 * {D} + 1.0 * {W}",
-                        "0.9 * {D} + 1.0 * {W}",
-                        "ASCE 7 Load Combination",
+                        "0.9 * D + 1.0 * W",
+                        "ASCE 7",
                     ],
                 )
                 self.myeqns.addline()
@@ -248,8 +379,8 @@ class Load:
                         "ASD Combo " + str(combo),
                         D,
                         f"{D}",
-                        "{D}",
-                        "ASCE 7 Load Combination",
+                        "D",
+                        "ASCE 7",
                     ],
                 )
                 return D
@@ -259,9 +390,9 @@ class Load:
                     [
                         "ASD Combo " + str(combo),
                         D + L,
-                        f"{D} + {L}" "{D} + {L}",
-                        "{D} + {L}" "{D} + {L}",
-                        "ASCE 7 Load Combination",
+                        f"{D} + {L}",
+                        "D + L",
+                        "ASCE 7",
                     ],
                 )
                 return D + L
@@ -272,8 +403,8 @@ class Load:
                         "ASD Combo " + str(combo),
                         D + max(L_r, S, R),
                         f"{D} + {max(L_r, S, R)}",
-                        "{D} + {max(L_r, S, R)}",
-                        "ASCE 7 Load Combination",
+                        "D + max(L_r, S, R)",
+                        "ASCE 7",
                     ],
                 )
                 return D + max(L_r, S, R)
@@ -284,8 +415,8 @@ class Load:
                         "ASD Combo " + str(combo),
                         D + 0.75 * L + 0.75 * max(L_r, S, R),
                         f"{D} + 0.75 * {L} + 0.75 * {max(L_r, S, R)}",
-                        "{D} + 0.75 * {L} + 0.75 * {max(L_r, S, R)}",
-                        "ASCE 7 Load Combination",
+                        "D + 0.75 * L + 0.75 * max(L_r, S, R)",
+                        "ASCE 7",
                     ],
                 )
                 return D + 0.75 * L + 0.75 * max(L_r, S, R)
@@ -296,8 +427,8 @@ class Load:
                         "ASD Combo " + str(combo),
                         D + 0.6 * W,
                         f"{D} + 0.6 * {W}",
-                        "{D} + 0.6 * {W}",
-                        "ASCE 7 Load Combination",
+                        "D + 0.6 * W",
+                        "ASCE 7",
                     ],
                 )
                 return D + 0.6 * W
@@ -308,8 +439,8 @@ class Load:
                         "ASD Combo " + str(combo),
                         D + 0.75 * L + 0.75 * 0.6 * W + 0.75 * max(L_r, S, R),
                         f"{D} + 0.75 * {L} + 0.75 * 0.6 * {W} + 0.75 * {max(L_r, S, R)}",
-                        "{D} + 0.75 * {L} + 0.75 * 0.6 * {W} + 0.75 * {max(L_r, S, R)}",
-                        "ASCE 7 Load Combination",
+                        "D + 0.75 * L + 0.75 * 0.6 * W + 0.75 * max(L_r, S, R)",
+                        "ASCE 7",
                     ],
                 )
                 return D + 0.75 * L + 0.75 * 0.6 * W + 0.75 * max(L_r, S, R)
@@ -320,8 +451,8 @@ class Load:
                         "ASD Combo " + str(combo),
                         0.6 * D + 0.6 * W,
                         f"0.6 * {D} + 0.6 * {W}",
-                        "0.6 * {D} + 0.6 * {W}",
-                        "ASCE 7 Load Combination",
+                        "0.6 * D + 0.6 * W",
+                        "ASCE 7",
                     ],
                 )
                 return 0.6 * D + 0.6 * W
@@ -377,67 +508,69 @@ def convert_to_float(frac_str):
 
 
 class Member:
-    shapes = pd.read_excel("aisc-shapes-14.xlsx", sheet_name="Database v15.0H")
-    df = shapes
     def __init__(self, designation):
+
         # Default is A36
         self.F_y = 36 * u.kips / (u.inch ** 2)
         self.F_u = 58 * u.kips / (u.inch ** 2)
         self.E = 29_000 * u.kips / (u.inch ** 2)
         self.myeqns = Equations()
-
-        # Check if plate, put PL
-        # if designation.find('PL') == True:
-        #     designation.
-
-        myedition = shapes["Edition"] == "14th"
-        mydesignation = shapes["Designation"] == designation
-        myshape = shapes.loc[myedition & mydesignation]
-        # This adds all of the attributes from the table as attributes of member
-        for column in myshape.columns:
+        if designation != "none":
             try:
-                exec(f"self.{column} = float(myshape[column])")
-            #                 print(f"'{column}' = {float(myshape[column])}")
+                shapes = pd.read_excel(
+                    "aisc-shapes-14.xlsx", sheet_name="Database v15.0H"
+                )
+                df = shapes
             except:
-                pass
-        # Fix Sha
+                # Used for module usage (Able to access file downloaded with module)
+                init_location = __file__
+                # print(init_location)
+                shapes_location = (
+                    init_location.replace("members.py", "") + "aisc-shapes-14.xlsx"
+                )
+                shapes = pd.read_excel(shapes_location, sheet_name="Database v15.0H")
+                df = shapes
 
-        #
-        import re
+            myedition = shapes["Edition"] == "14th"
+            mydesignation = shapes["Designation"] == designation
+            myshape = shapes.loc[myedition & mydesignation]
+            # This adds all of the attributes from the table as attributes of member
+            for column in myshape.columns:
+                try:
+                    exec(f"self.{column} = float(myshape[column])")
+                #                 print(f"'{column}' = {float(myshape[column])}")
+                except:
+                    pass
 
-        # print(designation)
-        # Space is necessary
-        designation = re.sub("[^X0-9/ ]", "", designation)
+            # print(designation)
+            # Space is necessary
+            designation = re.sub("[^X0-9/. ]", "", designation)
 
-        mydimensions = designation.split("X")
-        # print(mydimensions)
-        # print(convert_to_float(mydimensions[0]))
-        if len(mydimensions) == 3:
-            self.w_plate = convert_to_float(mydimensions[1]) * u.inch
-            self.t_plate = convert_to_float(mydimensions[2]) * u.inch
-        else:
-            self.w_plate = convert_to_float(mydimensions[0]) * u.inch
-            self.t_plate = convert_to_float(mydimensions[1]) * u.inch
+            mydimensions = designation.split("X")
 
-        try:
+            if len(mydimensions) == 3:
+                self.w_plate = convert_to_float(mydimensions[1]) * u.inch
+                self.t_plate = convert_to_float(mydimensions[2]) * u.inch
+            else:
+                self.w_plate = convert_to_float(mydimensions[0]) * u.inch
+                self.t_plate = convert_to_float(mydimensions[1]) * u.inch
 
-            self.A_g = self.A_g * u.inch ** 2
-        except:
-            # if self.A_g == 0:
-            self.A_g = self.w_plate * self.t_plate
-            # print(f"A_g = {self.w_plate} * {self.t_plate}\n\t= {self.A_g}")
-            self.myeqns.additem(
-                "A_g",
-                [
+            try:
+
+                self.A_g = self.A_g * u.inch ** 2
+            except:
+                self.A_g = self.w_plate * self.t_plate
+
+                self.myeqns.additem(
                     "A_g",
-                    self.A_g,
-                    f"{self.w_plate} * {self.t_plate}",
-                    "{self.w_plate} * {self.t_plate}",
-                    "Gross area",
-                ],
-            )
-        # else:
-        #     self.A_g = A_g * u.inch ** 2
+                    [
+                        "A_g",
+                        self.A_g,
+                        f"{self.w_plate} * {self.t_plate}",
+                        "w_plate * t_plate",
+                        "Gross area",
+                    ],
+                )
 
     def properties(self, F_y, F_u):
         # steel = "A36"
@@ -459,7 +592,7 @@ class Member:
                     "hole_size",
                     self.hole_size,
                     f"{self.bolt_size} + 1 / 8 * u.inch",
-                    "{self.bolt_size} + 1 / 8 * u.inch",
+                    "bolt_size + 1 / 8 * u.inch",
                     "Table J3.3 and b4.36 (16.1-130,16.1-20)",
                 ],
             )
@@ -471,13 +604,25 @@ class Member:
                     "hole_size",
                     self.hole_size,
                     f"{self.bolt_size} + 3 / 16 * u.inch",
-                    "{self.bolt_size} + 3 / 16 * u.inch",
+                    "bolt_size + 3 / 16 * u.inch",
                     "Table J3.3 and b4.36 (16.1-130,16.1-20)",
                 ],
             )
 
         self.A_hole = self.t_plate * self.hole_size
         self.A_holes = self.A_hole * self.holes
+
+        self.myeqns.additem(
+            "Area of holes",
+            [
+                "Area of holes",
+                self.A_holes,
+                f"{self.t_plate} * {self.hole_size} * {self.holes}",
+                "t_plate * hole_size * holes",
+                "",
+            ],
+        )
+
         A_holes = self.A_holes
 
         if len(stagger) > 0:
@@ -504,7 +649,7 @@ class Member:
                     "A_n from stagger",
                     A_n,
                     f"({A_g: .3} - {A_holes: .3}{stagger_equations}) * {load_transfer})",
-                    "({A_g: .3} - {A_holes: .3}{stagger_equations}) * {load_transfer})",
+                    "(A_g - A_holes + stagger_equations) * load_transfer)",
                     "Stagger factor from Eq 3.2",
                 ],
             )
@@ -518,7 +663,7 @@ class Member:
                     "A_n",
                     A_n,
                     f"({A_g: .3} - {A_holes: .3} * {load_transfer})",
-                    "({A_g: .3} - {A_holes: .3} * {load_transfer})",
+                    "(A_g - A_holes * load transfer)",
                     "Net area accounting for load transfer",
                 ],
             )
@@ -565,7 +710,7 @@ class Member:
                 "ASD Rupture strength",
                 P_n_net / 2,
                 f"{P_n_net:.3g} / 2",
-                "{P_n_net:.3g} / 2",
+                "P_n_net / 2",
                 "D2-2",
             ],
         )
@@ -605,7 +750,7 @@ class Member:
                     "U from other",
                     1 - (x_bar / l_plate),
                     f"1 - ({x_bar} / {l_plate})",
-                    "1 - ({x_bar} / {l_plate})",
+                    "1 - (x_bar / l_plate)",
                     "Table D3.1",
                 ],
             )
@@ -633,7 +778,7 @@ class Member:
                     "U from welded member",
                     ((3 * l ** 2) / (3 * l ** 2 + w ** 2)) * (1 - (x / l)),
                     f"(((3*{l}**2)/(3*{l}**2 + {w}**2))*(1 - ({x}/{l})))",
-                    "(((3*{l}**2)/(3*{l}**2 + {w}**2))*(1 - ({x}/{l})))",
+                    "(((3*l**2)/(3*l**2 + w**2))*(1 - (x/l)))",
                     "Table D3.1",
                 ],
             )
@@ -667,7 +812,7 @@ class Member:
                 "A_e",
                 A_e,
                 f"{A_n:.3g} * {effective_factor:.3g}",
-                "{A_n:.3g} * {effective_factor:.3g}",
+                "A_n * effective_factor",
                 "D3-1",
             ],
         )
@@ -681,7 +826,7 @@ class Member:
                 "Nominal strength gross",
                 P_n_gross,
                 f"{F_y:.3} * {A_g:.3}",
-                "{F_y:.3} * {A_g:.3}",
+                "F_y * A_g",
                 "D2-1",
             ],
         )
@@ -695,7 +840,7 @@ class Member:
                 "Nominal strength net",
                 P_n_net,
                 f"{F_u:.3} * {A_e:.3}",
-                "{F_u:.3} * {A_e:.3}",
+                "F_u * A_e",
                 "D2-2",
             ],
         )
@@ -721,7 +866,7 @@ class Member:
                 "Gross area in shear",
                 A_g,
                 f"{x_bolts} * {t_plate}",
-                "{x_bolts} * {t_plate}",
+                "x_bolts * t_plate",
                 "J4-5",
             ],
         )
@@ -741,7 +886,7 @@ class Member:
                 "Net area in shear",
                 A_nv,
                 f"{t_plate} * (({x_bolts}) - ({holes} - 0.5 * {rows}) * ({d_hole}))",
-                "{t_plate} * (({x_bolts}) - ({holes} - 0.5 * {rows}) * ({d_hole}))",
+                "t_plate * ((x_bolts) - (holes - 0.5 * rows) * (d_hole))",
                 "J4-5",
             ],
         )
@@ -751,7 +896,7 @@ class Member:
                 "Net area in tension",
                 A_nt,
                 f"{t_plate} * (({y_bolts}) - (0.5 * {rows}) * ({d_hole}))",
-                "{t_plate} * (({y_bolts}) - (0.5 * {rows}) * ({d_hole}))",
+                "t_plate * ((y_bolts) - (0.5 * rows) * (d_hole))",
                 "J4-5",
             ],
         )
@@ -761,7 +906,7 @@ class Member:
                 "R_n",
                 R_n,
                 f"0.6 * {F_u} * {A_nv:.3g} + {effective_factor} * {F_u} * {A_nt:.3g}",
-                "0.6 * {F_u} * {A_nv:.3g} + {effective_factor} * {F_u} * {A_nt:.3g}",
+                "0.6 * F_u * A_nv + effective_factor * F_u * A_nt",
                 "Eq 3.3",
             ],
         )
@@ -771,7 +916,7 @@ class Member:
                 "R_n_u",
                 R_n_u,
                 f"0.6 * {F_y} * {A_g:.3g} + {effective_factor} * {F_u} * {A_nt:.3g}",
-                "0.6 * {F_y} * {A_g:.3g} + {effective_factor} * {F_u} * {A_nt:.3g}",
+                "0.6 * F_y * A_g + effective_factor * F_u * A_nt",
                 "Eq 3.4",
             ],
         )
@@ -781,40 +926,60 @@ class Member:
                 "nominal_strength",
                 nominal_strength,
                 f"min([{R_n}, {R_n_u}])",
-                "min([{R_n}, {R_n_u}])",
+                "min([R_n, R_n_u])",
                 "D2-1 and D2-2",
             ],
         )
 
     # Compression
 
-    def axial_strength(self, L, K):
+    def axial_strength(self, Lx, Kx, Ly, Ky):
 
-        self.L = L * u.foot
-        self.L_cr = K * self.L
+        Lx = Lx * u.foot
+        Ly = Ly * u.foot
+        r_x = self.rx * u.inch
+        r_y = self.ry * u.inch
+        F_y = self.F_y
         E = self.E
         A_g = self.A_g
+        self.slenderness_x = (Kx * Lx.to(u.inch)) / r_x
+        self.slenderness_y = (Ky * Ly.to(u.inch)) / r_y
+        # if Ly != 0 and Ky != 0:
 
-        L = self.L
-
-        self.r_min = min(self.rx, self.ry) * u.inch
-
-        r_min = self.r_min
-
-        F_y = self.F_y
-
-        Slenderness = (L.to(u.inch) * K) / r_min
         self.myeqns.additem(
-            "Slenderness",
+            "Slenderness x",
             [
-                "Slenderness",
-                Slenderness,
-                f"({L} * {K})/{r_min}",
-                "(L * K)/r_min",
+                "Slenderness x",
+                self.slenderness_x,
+                f"({Lx} * {Kx})/{r_x}",
+                r"$$\frac{(L_x * K_x)}{r_x}$$",
                 "E3-2",
             ],
         )
 
+        self.myeqns.additem(
+            "Slenderness y",
+            [
+                "Slenderness y",
+                self.slenderness_y,
+                f"({Ly} * {Ky})/{r_y}",
+                r"$$\frac{(L_y * K_y)}{r_y}$$",
+                "E3-2",
+            ],
+        )
+        if self.slenderness_y > self.slenderness_x:
+            self.r_min = r_y
+            self.L = Ly
+            self.K = Ky
+            self.myeqns.maxes.append("Slenderness y")
+        else:
+            self.r_min = r_x
+            self.L = Lx
+            self.K = Kx
+            self.myeqns.maxes.append("Slenderness x")
+
+        self.slenderness = max(self.slenderness_x, self.slenderness_y)
+
         Slenderness_check = 4.71 * sqrt(E / F_y)
         self.myeqns.additem(
             "Slenderness check",
@@ -822,47 +987,49 @@ class Member:
                 "Slenderness check",
                 Slenderness_check,
                 f"4.71 * sqrt({E}/{F_y})",
-                "4.71 * sqrt(E/F_y)",
+                r"$$4.71 * \sqrt{\frac{E}{F_y}}$$",
                 "E3-2,E3-3",
             ],
         )
 
         from math import pi
 
-        F_e = (pi ** 2 * E) / Slenderness ** 2
+        F_e = (pi ** 2 * E) / self.slenderness ** 2
         self.myeqns.additem(
             "F_e",
             [
                 "F_e",
                 F_e,
-                f"(({pi:.3}**2 * {E})/ {Slenderness}**2)",
-                "((pi**2 * E)/ Slenderness**2)",
+                f"(({pi:.3}^2 * {E})/ {self.slenderness}^2)",
+                r"$$(\frac{(\pi^2 * E)}{Slenderness^2})$$",
                 "E3-2,E3-3",
             ],
         )
+        # Added as check
+        # self.myeqns.greens.append("F_e")
 
-        P_cr = (pi ** 2 * E * A_g) / Slenderness ** 2
+        P_cr = (pi ** 2 * E * A_g) / self.slenderness ** 2
         self.P_cr = P_cr
         self.myeqns.additem(
             "P_cr",
             [
                 "P_cr",
                 P_cr,
-                f"(({pi:.3}**2 * {E} * {A_g})/ {Slenderness}**2)",
-                "((pi**2 * E * A)/ Slenderness**2)",
+                f"(({pi:.3}^2 * {E} * {A_g})/ {self.slenderness}^2)",
+                r"$$(\frac{(\pi^2 * E * A)}{Slenderness^2})$$",
                 "E3-2,E3-3",
             ],
         )
 
-        if Slenderness > Slenderness_check:
+        if self.slenderness > Slenderness_check:
             F_cr = 0.877 * F_e
             self.myeqns.additem(
                 "F_cr",
                 [
-                    "Inelastic Critical Stress",
+                    "F_cr",
                     F_cr,
                     f"0.877 * {F_e}",
-                    "0.877 * F_e",
+                    "$$0.877 * F_e$$",
                     "E3-3",
                 ],
             )
@@ -871,10 +1038,10 @@ class Member:
             self.myeqns.additem(
                 "F_cr",
                 [
-                    "Elastic Critical Stress",
+                    "F_cr",
                     F_cr,
-                    f"0.658 **({F_y}/{F_e}) * {F_y}",
-                    "0.658 **(F_y/F_e) * F_y",
+                    f"(0.658 ^({F_y}/{F_e}) * {F_y})",
+                    r"$$(0.658^{(\frac{F_y}{F_e})} * F_y)$$",
                     "E3-2",
                 ],
             )
@@ -887,7 +1054,7 @@ class Member:
                 "P_n",
                 P_n,
                 f"{F_cr} * {A_g}",
-                "F_cr * A_g",
+                r"$$(F_{cr} * A_g)$$",
                 "E3-2",
             ],
         )
@@ -900,10 +1067,18 @@ class Member:
                 "P_n_LRFD",
                 P_n_LRFD,
                 f"{P_n} * {phi}",
-                "P_n * phi",
-                " ",
+                r"$$P_n * \phi$$",
+                "a",
             ],
         )
+        try:
+            if P_n_LRFD > self.LRFD_max:
+                self.myeqns.greens.append("P_n_LRFD")
+            else:
+                self.myeqns.reds.append("P_n_LRFD")
+        except:
+            print("theres none")
+
         omega = 1.67
         P_n_ASD = P_n / omega
         self.myeqns.additem(
@@ -912,11 +1087,17 @@ class Member:
                 "P_n_ASD",
                 P_n_ASD,
                 f"{P_n} / {omega}",
-                "P_n / omega",
-                " ",
+                r"$$\frac{P_n}{\omega}$$",
+                "a",
             ],
         )
-        # if self.slenderness
+        try:
+            if P_n_ASD > self.ASD_max:
+                self.myeqns.greens.append("P_n_ASD")
+            else:
+                self.myeqns.reds.append("P_n_ASD")
+        except:
+            pass
 
     def available_strength(self, L1, L2, K1, K2):
         r_x = self.rx
@@ -935,11 +1116,20 @@ class Member:
                 "factor of safety",
                 factor_of_safety,
                 f"({P_cr} / {myload})",
-                "(P_cr / myload)",
-                " ",
+                r"$\frac({P_{cr}}{myload})$",
+                "a",
             ],
         )
 
+    def slenderness_hss(self):
+        print(self.b__tdes)
+        print(1.4 * sqrt(self.E / self.F_y))
+        if self.b__tdes <= 1.4 * sqrt(self.E / self.F_y):
+
+            print("Not slender")
+        else:
+            print("Slender")
+
     def local_stability(self):
         E = self.E
         F_y = self.F_y
@@ -953,6 +1143,10 @@ class Member:
         third = (self.ddet - 2 * self.kdes) / tw
         print(first, second, third)
 
+    def add_loads(self, loads):
+        self.LRFD_max = loads.LRFD_max
+        self.ASD_max = loads.ASD_max
+
 
 class purlin:
     def __init__(self, weight, count):
@@ -967,3 +1161,30 @@ class truss:
         self.y = convert_to_float(y) * u.foot
         self.length = convert_to_float(length) * u.foot
         self.spacing = spacing * u.feet
+
+
+class Frame:
+    def __init__(self, H, L):
+        self.H = H * u.foot
+        self.L = L * u.foot
+
+    def find_g(self, A, B):
+        H = self.H
+        L = self.L
+
+        if A == "Pin":
+            g_a = 10
+        elif A == "Fixed":
+            g_a = 1
+        else:
+            g_a = (A[0] / H) / (A[1] / L)
+
+        if B == "Pin":
+            g_b = 10
+        elif B == "Fixed":
+            g_b = 1
+        else:
+            g_b = (B[0] / H) / (B[1] / L)
+
+        print(f"g_a = {g_a}")
+        print(f"g_b = {g_b}")
